CBOR.Encoder protocol (cbor v1.0.2) View Source

Link to this section Summary

Types

t()

All the types that implement this protocol.

Functions

Converts an Elixir data type to its representation in CBOR.

Link to this section Types

Specs

t() :: term()

All the types that implement this protocol.

Link to this section Functions

Link to this function

encode_into(element, acc)

Converts an Elixir data type to its representation in CBOR.